@@ -1,3 +1,4 @@
+from unicodedata import numeric
 from ..models import PLAYER, SKILLS
 import copy
 
@@ -54,3 +55,32 @@ def add_skillname_to_profile(profile: dict) -> dict:
         # All skills are shifted by 1 index(See models.py)
         profile['skillvalues'][i]['skillname'] = SKILLS[skill['id'] + 1]
     return profile
+
+
+def is_valid_category(categoryId: int):
+    # Category must be [0-41]
+    if(categoryId < 0 or categoryId > 41):
+        raise Exception("Cateogory must be between 0 and 41 inclusive")
+
+
+def unwrap_category_dict(content):
+    ret_dict = {}
+    for letter in  content['alpha']:
+        ret_dict[letter['letter']] = letter['items']
+
+    return ret_dict
+
+def abbrv_price_to_num(price: str) -> int:
+    ret_val = 0
+    last_letter = price[-1]
+    if last_letter == 'k':
+        num = int(float(price[:-1]) * 1000)
+        return num
+    elif last_letter == 'm':
+        num = int(float(price[:-1]) * 1000000)
+        return num
+    elif last_letter == 'b':
+        num = int(float(price[:-1]) * 1000000000)
+        return num
+    else:
+        return int(price)
