@@ -13,43 +13,43 @@ def bestiary():
 
 class TestBestiary():
     """Test Get Bestiary Data"""
-    def test_get_bestiary_data(self, bestiary):
+    def test_get_bestiary_data(self, bestiary: Bestiary):
         response = bestiary.get_beast(89) # Unicorn
 
         assert isinstance(response, dict)
         assert response['name'] == 'Unicorn'
 
-    def test_get_bestiary_data_argument_type_error(self, bestiary):
+    def test_get_bestiary_data_argument_type_error(self, bestiary: Bestiary):
         with pytest.raises(TypeError):
             response = bestiary.get_beast("Unicorn") # Wrong argument type
 
     """Test Bestiary Search"""
-    def test_get_beast_by_term(self, bestiary):
+    def test_get_beast_by_term(self, bestiary: Bestiary):
         response = bestiary.get_beast_by_term("cow")
 
         assert isinstance(response, list)
         assert 'label' in response[0]
         assert 'value' in response[0]
 
-    def test_get_beast_by_two_terms(self, bestiary):
+    def test_get_beast_by_two_terms(self, bestiary: Bestiary):
         response = bestiary.get_beast_by_term("cow+rabbit")
 
         assert isinstance(response, list)
         assert 'label' in response[0]
         assert 'value' in response[0]
 
-    def test_get_beast_by_ter_beast_does_not_exist(self, bestiary):
+    def test_get_beast_by_ter_beast_does_not_exist(self, bestiary: Bestiary):
         response = bestiary.get_beast_by_term("nobeasthasthisname")
 
         assert isinstance(response, list)
         assert response[0] == "none"
 
-    def test_get_beast_by_term_argument_type_error(self, bestiary):
+    def test_get_beast_by_term_argument_type_error(self, bestiary: Bestiary):
         with pytest.raises(TypeError):
             response = bestiary.get_beast_by_term(12)
 
     """Test Beast Names By First Letter"""
-    def test_get_beast_by_first_letter(self, bestiary):
+    def test_get_beast_by_first_letter(self, bestiary: Bestiary):
         response = bestiary.get_beast_by_first_letter('q')
 
         assert isinstance(response, list)
