@@ -12,7 +12,7 @@ def runemetrics():
 
 class TestRuneMetric():
     """Tests for get_monthly_experience"""
-    def test_get_monthly_experience(self, runemetrics):
+    def test_get_monthly_experience(self, runemetrics: Runemetrics):
         # Test for a successful call
         response = runemetrics.get_monthly_experience('Phyrexz', 'defence')
 
@@ -22,40 +22,40 @@ class TestRuneMetric():
         assert response['monthlyXpGain'][0]['skillId'] == 1
         assert response['monthlyXpGain'][0]['skillName'] == 'defence'
 
-    def test_get_monthly_experience_id_out_of_bounds(self, runemetrics):
+    def test_get_monthly_experience_id_out_of_bounds(self, runemetrics: Runemetrics):
         # Test if exception is thrown if skill index is out of bounds
         with pytest.raises(Exception):
             runemetrics.get_monthly_experience('Phyrexz', 28)
 
-    def test_get_monthly_experience_invalid_skill_string(self, runemetrics):
+    def test_get_monthly_experience_invalid_skill_string(self, runemetrics: Runemetrics):
         # Test if Exception is thrown when invalid string for skill name is supplied
         with pytest.raises(Exception):
             runemetrics.get_monthly_experience('Phyrexz', 'notaskillname')
 
-    def test_get_monthly_experience_argument_type_error(self, runemetrics):
+    def test_get_monthly_experience_argument_type_error(self, runemetrics: Runemetrics):
         # Test if TypeError is thrown when invalid type is supplied as argument
         with pytest.raises(TypeError):
             response = runemetrics.get_monthly_experience(12, 12)
 
 
     """Tests for get_quests"""
-    def test_get_quests(self, runemetrics):
+    def test_get_quests(self, runemetrics: Runemetrics):
         response = runemetrics.get_quests('Phyrexz')
 
         assert isinstance(response, dict)
         assert isinstance(response['quests'], list)
 
-    def test_get_quests_non_str_username(self, runemetrics):
+    def test_get_quests_non_str_username(self, runemetrics: Runemetrics):
         with pytest.raises(TypeError):
             response = runemetrics.get_quests(12)
 
 
     """Tests for get_profile"""
-    def test_get_profile(self, runemetrics):
+    def test_get_profile(self, runemetrics: Runemetrics):
         response = runemetrics.get_profile('Phyrexz')
 
         assert isinstance(response, dict)
 
-    def test_get_profile_non_int_parameter(self, runemetrics):
+    def test_get_profile_non_int_parameter(self, runemetrics: Runemetrics):
         with pytest.raises(TypeError):
             response = runemetrics.get_profile('Phyrexz', "12")
